<?php
/**
 * HTTP parsing tests
 *
 * SimplePie
 *
 * A PHP-Based RSS and Atom Feed Framework.
 * Takes the hard work out of managing a complete RSS/Atom solution.
 *
 * Copyright (c) 2004-2016, Ryan Parman, Sam Sneddon, Ryan McCue, and contributors
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, are
 * permitted provided that the following conditions are met:
 *
 * 	* Redistributions of source code must retain the above copyright notice, this list of
 * 	  conditions and the following disclaimer.
 *
 * 	* Redistributions in binary form must reproduce the above copyright notice, this list
 * 	  of conditions and the following disclaimer in the documentation and/or other materials
 * 	  provided with the distribution.
 *
 * 	* Neither the name of the SimplePie Team nor the names of its contributors may be used
 * 	  to endorse or promote products derived from this software without specific prior
 * 	  written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS
 * OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS
 * AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * @package SimplePie
 * @copyright 2004-2016 Ryan Parman, Sam Sneddon, Ryan McCue
 * @author Ryan Parman
 * @author Sam Sneddon
 * @author Ryan McCue
 * @link http://simplepie.org/ SimplePie
 * @license http://www.opensource.org/licenses/bsd-license.php BSD License
 */

require_once dirname(__FILE__) . '/bootstrap.php';

class HTTPParserTest extends PHPUnit\Framework\TestCase
{
	public static function chunkedProvider()
	{
		return array(
			array(
				"25\r\nThis is the data in the first chunk\r\n\r\n1A\r\nand this is the second one\r\n0\r\n",
				"This is the data in the first chunk\r\nand this is the second one"
			),
			array(
				"02\r\nab\r\n04\r\nra\nc\r\n06\r\nadabra\r\n0\r\nnothing\n",
				"abra\ncadabra"
			),
			array(
				"02\r\nab\r\n04\r\nra\nc\r\n06\r\nadabra\r\n0c\r\n\nall we got\n",
				"abra\ncadabra\nall we got\n"
			),
		);
	}

	/**
	 * @dataProvider chunkedProvider
	 */
	public function testChunkedNormal($data, $expected)
	{
		$data = "HTTP/1.1 200 OK\r\nContent-Type: text/plain\r\nTransfer-Encoding: chunked\r\n\r\n" . $data;
		$data = SimplePie_HTTP_Parser::prepareHeaders($data);
		$parser = new SimplePie_HTTP_Parser($data);
		$this->assertTrue($parser->parse());
		$this->assertSame(1.1, $parser->http_version);
		$this->assertSame(200, $parser->status_code);
		$this->assertSame('OK', $parser->reason);
		$this->assertSame(array('content-type' => 'text/plain'), $parser->headers);
		$this->assertSame($expected, $parser->body);

	}

	/**
	 * @dataProvider chunkedProvider
	 */
	public function testChunkedProxy($data, $expected)
	{
		$data = "HTTP/1.0 200 Connection established\r\n\r\nHTTP/1.1 200 OK\r\nContent-Type: text/plain\r\nTransfer-Encoding: chunked\r\n\r\n" . $data;
		$data = SimplePie_HTTP_Parser::prepareHeaders($data);
		$parser = new SimplePie_HTTP_Parser($data);
		$this->assertTrue($parser->parse());
		$this->assertSame(1.1, $parser->http_version);
		$this->assertSame(200, $parser->status_code);
		$this->assertSame('OK', $parser->reason);
		$this->assertSame(array('content-type' => 'text/plain'), $parser->headers);
		$this->assertSame($expected, $parser->body);
	}

	/**
	 * @dataProvider chunkedProvider
	 */
	public function testChunkedProxy11($data, $expected)
	{
		$data = "HTTP/1.1 200 Connection established\r\n\r\nHTTP/1.1 200 OK\r\nContent-Type: text/plain\r\nTransfer-Encoding: chunked\r\n\r\n" . $data;
		$data = SimplePie_HTTP_Parser::prepareHeaders($data);
		$parser = new SimplePie_HTTP_Parser($data);
		$this->assertTrue($parser->parse());
		$this->assertSame(1.1, $parser->http_version);
		$this->assertSame(200, $parser->status_code);
		$this->assertSame('OK', $parser->reason);
		$this->assertSame(array('content-type' => 'text/plain'), $parser->headers);
		$this->assertSame($expected, $parser->body);
	}
}
